/**
 ** A Virtual Host Monitor
 **
 ** Copyright 2009 Gary Wuertz gary@issiweb.com
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef TOPVHOST_MONITOR_H
#define TOPVHOST_MONITOR_H

#include <vector>

#include <sys/types.h>
#include "config.h"
#include "vhost.h"
#include "topvhost.h"
/**
 * The watchlist enumerates what will be watched
 */
class watchList {
public:
 int                                namelen;    // length of longest domain name
 std::map<std::string,std::string>  watch;      // domain=>logfile
};
/**
 * The vhost monitor
 */
class Monitor
{
public:
  vhost*                    getHosts(topvhost *app);
  bool                      getInput(topvhost *app);
  watchList*                getWatchList(Config * conf);
  void                      init(topvhost *app);
  void                      paintHeader(topvhost *app);
  void                      quit(topvhost *app);
  void                      throwError(const char* tag);
  void                      update(topvhost *app);
private:
  std::map<int,int>         watch;            // inotify dispatch
  int                       notify;           // inotify file handle
  int                       nhosts;           // number of vhosts
  long                      meter;            // how many bytes read
  int                       hits;             // hit total for all hosts
  vhost*                    hosts;            // the vhosts
  vhost*                    hlist;            // the sorted vhost list
};
#endif
